summaryrefslogtreecommitdiff
path: root/src/main.cpp
diff options
context:
space:
mode:
authorEugenio Favalli <elvenprogrammer@gmail.com>2006-12-12 15:52:42 +0000
committerEugenio Favalli <elvenprogrammer@gmail.com>2006-12-12 15:52:42 +0000
commit16cb089845b3adcdd605d138d903bd7ada0f9e03 (patch)
treed43dea9b474d9cceee0de653e23f9aa2c556009e /src/main.cpp
parent15d969bb200b3e820982ccc8cb157231d7befa7e (diff)
downloadmana-client-16cb089845b3adcdd605d138d903bd7ada0f9e03.tar.gz
mana-client-16cb089845b3adcdd605d138d903bd7ada0f9e03.tar.bz2
mana-client-16cb089845b3adcdd605d138d903bd7ada0f9e03.tar.xz
mana-client-16cb089845b3adcdd605d138d903bd7ada0f9e03.zip
Added Adler32 checksum for updates
Diffstat (limited to 'src/main.cpp')
-rw-r--r--src/main.cpp9
1 files changed, 6 insertions, 3 deletions
diff --git a/src/main.cpp b/src/main.cpp
index eebb92bb..f54b0792 100644
--- a/src/main.cpp
+++ b/src/main.cpp
@@ -380,19 +380,22 @@ void parseOptions(int argc, char *argv[], Options &options)
}
/**
* Reads the file "updates/resources.txt" and attempts to load each update
* mentioned in it.
*/
void loadUpdates()
{
- const std::string updatesFile = "updates/resources.txt";
+ const std::string updatesFile = "updates/resources2.txt";
ResourceManager *resman = ResourceManager::getInstance();
std::vector<std::string> lines = resman->loadTextFile(updatesFile);
std::string homeDir = config.getValue("homeDir", "");
for (unsigned int i = 0; i < lines.size(); ++i)
{
- resman->addToSearchPath(homeDir + "/updates/" + lines[i], false);
+ std::stringstream line(lines[i]);
+ std::string filename;
+ line >> filename;
+ resman->addToSearchPath(homeDir + "/updates/" + filename, false);
}
}
@@ -380,19 +380,22 @@ void parseOptions(int argc, char *argv[], Options &options)
}
/**
- * Reads the file "updates/resources.txt" and attempts to load each update
+ * Reads the file "updates/resources2.txt" and attempts to load each update
* mentioned in it.
*/